==> zio-aws-xray_2.13-5.17.130.6-sources.jar: zio/aws/xray/model/GetGroupsRequest.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.xray.model.primitives.GetGroupsNextToken
import scala.jdk.CollectionConverters._
final case class GetGroupsRequest(
    nextToken: Option[GetGroupsNextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.xray.model.GetGroupsRequest = {
    import GetGroupsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.GetGroupsRequest
      .builder()
      .optionallyWith(
        nextToken.map(value =>
          GetGroupsNextToken.unwrap(value): java.lang.String
        )
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.xray.model.GetGroupsRequest.ReadOnly =
    zio.aws.xray.model.GetGroupsRequest.wrap(buildAwsValue())
}
object GetGroupsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.xray.model.GetGroupsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.GetGroupsRequest =
      zio.aws.xray.model.GetGroupsRequest(nextToken.map(value => value))
    def nextToken: Option[GetGroupsNextToken]
    def getNextToken: ZIO[Any, AwsError, GetGroupsNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.GetGroupsRequest
  ) extends zio.aws.xray.model.GetGroupsRequest.ReadOnly {
    override val nextToken: Option[GetGroupsNextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.xray.model.primitives.GetGroupsNextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.GetGroupsRequest
  ): zio.aws.xray.model.GetGroupsRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-xray_2.13-5.17.167.1-sources.jar: zio/aws/xray/model/GetGroupsRequest.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.xray.model.primitives.GetGroupsNextToken
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetGroupsRequest(
    nextToken: Optional[GetGroupsNextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.xray.model.GetGroupsRequest = {
    import GetGroupsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.GetGroupsRequest
      .builder()
      .optionallyWith(
        nextToken.map(value =>
          GetGroupsNextToken.unwrap(value): java.lang.String
        )
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.xray.model.GetGroupsRequest.ReadOnly =
    zio.aws.xray.model.GetGroupsRequest.wrap(buildAwsValue())
}
object GetGroupsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.xray.model.GetGroupsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.GetGroupsRequest =
      zio.aws.xray.model.GetGroupsRequest(nextToken.map(value => value))
    def nextToken: Optional[GetGroupsNextToken]
    def getNextToken: ZIO[Any, AwsError, GetGroupsNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.GetGroupsRequest
  ) extends zio.aws.xray.model.GetGroupsRequest.ReadOnly {
    override val nextToken: Optional[GetGroupsNextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.xray.model.primitives.GetGroupsNextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.GetGroupsRequest
  ): zio.aws.xray.model.GetGroupsRequest.ReadOnly = new Wrapper(impl)
}
